#ifndef PANGO_FEATURES_H
#define PANGO_FEATURES_H

#define PANGO_VERSION_MAJOR 1
#define PANGO_VERSION_MINOR 57
#define PANGO_VERSION_MICRO 1

#define PANGO_VERSION_STRING "1.57.1"

#endif /* PANGO_FEATURES_H */
